@@ -1,7 +1,7 @@
 /*!
 `adbook` is a simple SSG powered by [asciidoctor]
 
-The name came from [mdBook].
+The name came from [mdBook] and `adbook` aims to be an alternative to it.
 
 [asciidoctor]: https://asciidoctor.org/
 [mdBook]: https://rust-lang.github.io/mdBook/
